@@ -103,9 +103,13 @@ def bw_items(repo, args):
                 prepare_dependencies(node)
                 table = [[bold(_("attribute")), bold(_("value"))]]
                 for attribute in BUILTIN_ITEM_ATTRIBUTES:
+                    if args['attr'] and attribute != args['attr']:
+                        continue
                     table.append(ROW_SEPARATOR)
                     value = getattr(item, attribute)
-                    if isinstance(value, Collection):
+                    if isinstance(value, str):
+                        table.append([attribute, value])
+                    elif isinstance(value, Collection):
                         value = sorted(value) or [""]
                         table.append([attribute, value.pop(0)])
                         for element in value:
@@ -117,7 +121,9 @@ def bw_items(repo, args):
                         table.append([attribute, repr(value)])
                 page_lines(render_table(table))
             else:
-                if args['show_sdict']:
+                if item.ITEM_TYPE_NAME == "action":
+                    statedict = item.attributes
+                elif args['show_sdict']:
                     statedict = item.sdict()
                 else:
                     statedict = item.cdict()
