@@ -1,11 +1,11 @@
 from collections import OrderedDict
 from contextlib import suppress
 from decimal import Decimal
-from sys import version_info
+from sys import exit, version_info
 
 from ..metadata import metadata_to_json
 from ..utils import Fault, list_starts_with
-from ..utils.cmdline import get_target_nodes
+from ..utils.cmdline import exit_on_keyboardinterrupt, get_target_nodes
 from ..utils.dicts import (
     delete_key_at_path,
     replace_key_at_path,
@@ -49,8 +49,8 @@ def _colorize_path(
     hide_node,
 ):
     if not isinstance(value_at_key_path(metadata, path), (dict, list, tuple, set)):
-        # only last source relevant for atomic types
-        sources = [sources[-1]]
+        # only highest-priority source relevant for atomic types
+        sources = [sources[0]]
     sources_filtered = False
     for src in sources.copy():
         if (
@@ -84,7 +84,7 @@ def _sort_dict_colorblind(old_dict):
     else:
         new_dict = {}
 
-    for key in sorted(old_dict.keys(), key=lambda k: ansi_clean(k)):
+    for key in sorted(old_dict.keys(), key=ansi_clean):
         if isinstance(old_dict[key], dict):
             new_dict[key] = _sort_dict_colorblind(old_dict[key])
         else:
@@ -93,13 +93,14 @@ def _sort_dict_colorblind(old_dict):
     return new_dict
 
 
+@exit_on_keyboardinterrupt
 def bw_metadata(repo, args):
     target_nodes = get_target_nodes(repo, args['targets'])
     key_paths = sorted([
         tuple(path.strip().split("/")) for path in args['keys'] if path
-    ]) or [tuple()]
+    ]) or [()]
     if len(target_nodes) > 1:
-        if key_paths == [tuple()]:
+        if key_paths == [()]:
             io.stdout(_("{x} at least one key is required when viewing multiple nodes").format(x=red("!!!")))
             exit(1)
         if args['blame']:
