@@ -1,11 +1,5 @@
-# -*- coding: utf-8 -*-
-from __future__ import unicode_literals
-
 from datetime import datetime
-try:
-    from itertools import zip_longest
-except ImportError:  # Python 2
-    from itertools import izip_longest as zip_longest
+from itertools import zip_longest
 from sys import exit
 
 from ..concurrency import WorkerPool
@@ -116,13 +110,13 @@ def stats_summary(results, include_stdout, include_stderr):
 
 def bw_run(repo, args):
     errors = []
-    target_nodes = get_target_nodes(repo, args['target'], adhoc_nodes=args['adhoc_nodes'])
-    pending_nodes = target_nodes[:]
+    target_nodes = get_target_nodes(repo, args['targets'])
+    pending_nodes = target_nodes.copy()
     io.progress_set_total(len(pending_nodes))
 
     repo.hooks.run_start(
         repo,
-        args['target'],
+        args['targets'],
         target_nodes,
         args['command'],
     )
@@ -176,7 +170,7 @@ def bw_run(repo, args):
 
     repo.hooks.run_end(
         repo,
-        args['target'],
+        args['targets'],
         target_nodes,
         args['command'],
         duration=datetime.now() - start_time,
