@@ -5,7 +5,7 @@ import re
 from tomlkit import dumps as toml_dump, parse as toml_parse
 
 from .exceptions import NoSuchGroup, NoSuchNode, RepositoryError
-from .utils import cached_property, error_context, get_file_contents, names
+from .utils import cached_property, error_context, Fault, get_file_contents, names
 from .utils.dicts import (
     dict_to_toml,
     hash_statedict,
@@ -19,7 +19,7 @@ from .utils.text import mark_for_translation as _, toml_clean, validate_name
 
 GROUP_ATTR_DEFAULTS = {
     'cmd_wrapper_inner': "export LANG=C; {}",
-    'cmd_wrapper_outer': "sudo sh -c {}",
+    'cmd_wrapper_outer': "sudo -u {1} sh -c {0}",
     'lock_dir': "/var/lib/bundlewrap",
     'dummy': False,
     'kubectl_context': None,
@@ -40,11 +40,13 @@ GROUP_ATTR_DEFAULTS = {
     # soon as it appears in the repo - which is probably not what
     # people want.
     'os_version': (0,),
+    'password': None,
     # On some nodes, we maybe have pip2 and pip3 installed, but there's
     # no way of knowing which one the user wants. Or maybe there's only
     # one of them, but there's no symlink to pip, only pip3.
     'pip_command': 'pip',
     'use_shadow_passwords': True,
+    'username': None,
 }
 
 GROUP_ATTR_TYPES = {
@@ -61,11 +63,13 @@ GROUP_ATTR_TYPES = {
     'metadata': dict,
     'os': str,
     'os_version': TUPLE_OF_INTS,
+    'password': (Fault, str, type(None)),
     'pip_command': str,
     'subgroups': COLLECTION_OF_STRINGS,
     'subgroup_patterns': COLLECTION_OF_STRINGS,
     'supergroups': COLLECTION_OF_STRINGS,
     'use_shadow_passwords': bool,
+    'username': (Fault, str, type(None)),
 }
 
 
