@@ -22,6 +22,12 @@ from bundlewrap.utils.ui import io
 from bundlewrap.operations import run_local
 
 
+ALLOWED_ITEM_AUTO_ATTRIBUTES = {
+    'after',
+    'before',
+    'needed_by',
+    'needs',
+}
 BUILTIN_ITEM_ATTRIBUTES = {
     'after': set(),
     'before': set(),
@@ -565,7 +571,9 @@ class Item:
                     status_code = self.STATUS_OK
                 elif show_diff or interactive:
                     if status_before.must_be_created:
-                        details = self.display_on_create(copy(status_before.cdict))
+                        cdict = copy(status_before.cdict)
+                        cdict.update(self.when_creating)
+                        details = self.display_on_create(cdict)
                     elif status_before.must_be_deleted:
                         details = self.display_on_delete(copy(status_before.sdict))
                     else:
@@ -731,8 +739,26 @@ class Item:
         """
         raise NotImplementedError()
 
+    def get_auto_attrs(self, items):
+        """
+        Return a dict with any number of attributes. The respective
+        sets will be merged with the user-supplied values. For example:
+
+            return {
+                'needs': {
+                    'file:/foo',
+                },
+            }
+
+        Note that only attributes from ALLOWED_ITEM_AUTO_ATTRIBUTES are
+        allowed.
+        """
+        return {}
+
     def get_auto_deps(self, items):
         """
+        DEPRECATED remove in 5.0, use get_auto_attrs instead
+
         Return a list of item IDs this item should have dependencies on.
 
         Be very careful when using this. There are few circumstances
@@ -810,7 +836,9 @@ class Item:
     def display_on_create(self, cdict):
         """
         Given a cdict as implemented above, modify it to better suit
-        interactive presentation when an item is created.
+        interactive presentation when an item is created. If there are
+        any when_creating attributes, they will be added to the cdict
+        before it is passed to this method.
 
         MAY be overridden by subclasses.
         """
