@@ -71,6 +71,14 @@ class SvcOpenBSD(Item):
 
     def get_canned_actions(self):
         return {
+            'stop': {
+                'command': "/etc/rc.d/{0} stop".format(self.name),
+                'needed_by': {self.id},
+            },
+            'stopstart': {
+                'command': "/etc/rc.d/{0} stop && /etc/rc.d/{0} start".format(self.name),
+                'needs': {self.id},
+            },
             'restart': {
                 'command': "/etc/rc.d/{} restart".format(self.name),
                 'needs': {
@@ -82,10 +90,6 @@ class SvcOpenBSD(Item):
                     self.id,
                 },
             },
-            'stopstart': {
-                'command': "/etc/rc.d/{0} stop && /etc/rc.d/{0} start".format(self.name),
-                'needs': {self.id},
-            },
         }
 
     def sdict(self):
