@@ -366,7 +366,8 @@ class Repository(MetadataGenerator):
                         not isfile(filepath) or \
                         filename.startswith("_"):
                     continue
-                infodict = untoml(toml_parse(get_file_contents(filepath)))
+                with error_context(filepath=filepath):
+                    infodict = untoml(toml_parse(get_file_contents(filepath)))
                 infodict['file_path'] = filepath
                 yield filename[:-5], infodict
 
@@ -423,6 +424,7 @@ class Repository(MetadataGenerator):
 
     @property
     def groups(self):
+        # TODO 5.0 make this a cached set
         return sorted(self.group_dict.values())
 
     def hash(self):
@@ -430,6 +432,7 @@ class Repository(MetadataGenerator):
 
     @property
     def nodes(self):
+        # TODO 5.0 make this a cached set
         return sorted(self.node_dict.values())
 
     def nodes_in_all_groups(self, group_names):
